# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2017-01-11 16:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('stonefilters', '0001_initial'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='TestModel',
            new_name='TstModel',
        ),
    ]



# from distutils.core import setup
from setuptools import setup, find_packages

setup(
    name='stoneFilters',
    version='0.1.0',
    packages=find_packages(),
    license='',
    long_description=open('README.rst').read(),
    url='http://www.stoneworksolutions.net',
    author='Antonio Palomo Cardenas',
    author_email='antonio.palomo@stoneworksolutions.net',
    package_data={'': ['*.html']},
    include_package_data=True,
    install_requires=['StonePlugin'],
)
